@@ -34,10 +34,6 @@
 #include <gvfsbackend.h>
 #include <gvfsdbus.h>
 
-#if HAVE_KEYRING
-#  include <dbus/dbus.h>
-#endif
-
 static char *spawner_id = NULL;
 static char *spawner_path = NULL;
 
@@ -70,10 +66,6 @@ daemon_init (void)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
   
-#if HAVE_KEYRING
-  /* gnome-keyring needs d-bus threads properly initialized */
-  dbus_threads_init_default ();
-#endif
   g_type_init ();
 
   g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, log_debug, NULL);
@@ -155,6 +147,7 @@ call_spawned_cb (GVfsDBusSpawner *proxy,
 
   if (! gvfs_dbus_spawner_call_spawned_finish (proxy, res, &error))
     {
+      g_dbus_error_strip_remote_error (error);
       g_printerr ("call_spawned_cb: Error sending a message: %s (%s, %d)\n",
                   error->message, g_quark_to_string (error->domain), error->code);
       g_error_free (error);
@@ -167,6 +160,7 @@ call_spawned_cb (GVfsDBusSpawner *proxy,
 static void
 send_spawned (gboolean succeeded, 
               char *error_message,
+              guint32 error_code,
               GDestroyNotify callback,
               gpointer user_data)
 {
@@ -210,6 +204,7 @@ send_spawned (gboolean succeeded,
   gvfs_dbus_spawner_call_spawned (proxy, 
                                   succeeded,
                                   error_message,
+                                  error_code,
                                   NULL,
                                   (GAsyncReadyCallback) call_spawned_cb,
                                   data);
@@ -311,10 +306,9 @@ on_name_lost (GDBusConnection *connection,
       else
         {
           s = g_strdup_printf (_("mountpoint for %s already running"), data->mountable_name);
-          g_printerr (_("Error: %s"), s);
-          g_printerr ("\n");
+          send_spawned (FALSE, s, G_IO_ERROR_ALREADY_MOUNTED, spawned_failed_cb, data);
           g_free (s);
-          process_result = 1;
+          return;
         }
     }
   g_main_loop_quit (loop);
@@ -327,20 +321,18 @@ on_name_acquired (GDBusConnection *connection,
 {
   DaemonData *data = user_data;
 
-  g_warning ("daemon-main.c: Acquired the name on the session message bus\n");
-  
   already_acquired = TRUE;
   
   data->daemon = g_vfs_daemon_new (FALSE, FALSE);
   if (data->daemon == NULL)
     {
-      send_spawned (FALSE, _("error starting mount daemon"), spawned_failed_cb, data);
+      send_spawned (FALSE, _("error starting mount daemon"), G_IO_ERROR_FAILED, spawned_failed_cb, data);
       return;
     }
 
   g_vfs_daemon_set_max_threads (data->daemon, data->max_job_threads);
 
-  send_spawned (TRUE, NULL, spawned_succeeded_cb, data);
+  send_spawned (TRUE, NULL, 0, spawned_succeeded_cb, data);
 }
 
 static gboolean
